@@ -4,6 +4,7 @@ import json
 import logging
 import re
 
+from subprocess import TimeoutExpired
 from retry import retry
 from .download_bitwarden import DownloadBitwarden
 
@@ -151,7 +152,7 @@ class Bitwarden(object):
           bw.get_data(items)
           assert isinstance(bw.data['aws'],dict)
         """
-        print("Sync bitwarden data...")
+        print("Syncing bitwarden data...")
         bitwarden_app = self.bitwarden_exe(
             "sync",
             "--session",
@@ -203,6 +204,7 @@ class Bitwarden(object):
                 "Invalid bitwarden collection or key name or no access to collection for this user!"
             )
 
+    @retry(TimeoutExpired, delay=5, tries=3)
     def get_attachment(self, item_name, file_name, output_folder=os.getcwd()):
         """
         Downloads attachment file from particular item to current working directory
@@ -230,6 +232,13 @@ class Bitwarden(object):
         if not os.path.exists(output_folder):
             os.mkdir(output_folder)
 
+        print("Syncing bitwarden data...")
+        bitwarden_app = self.bitwarden_exe(
+            "sync",
+            "--session",
+            self.session_key,
+        )
+
         # Get item ID
         bitwarden_app = self.bitwarden_exe(
             "get",
